@@ -1,6 +1,7 @@
 import ctypes
+import sys
 from ctypes import *
-from algorithmLib.Function import project_root_path
+
 
 class pesqstruct(Structure):
  _fields_ = [
@@ -9,7 +10,7 @@ class pesqstruct(Structure):
 
 def cal_pesq(reffile, testfile,samplerate):
     pesqs = pesqstruct()
-    mydll = ctypes.windll.LoadLibrary(project_root_path() + 'algorithmLib/PESQ/PY_PESQ.dll')
+    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/PY_PESQ.dll')
     inputFile = c_char_p(bytes(reffile.encode('utf-8')))#create_unicode_buffer(inFile.encode('utf-8'), len(inFile))
     outputFile = c_char_p(bytes(testfile.encode('utf-8')))#create_unicode_buffer(outFile.encode('utf-8'), len(outFile))
     if samplerate == 8000:
