@@ -64,7 +64,7 @@ def startvqt(srcFile=None, degFile=None, samplerate=48000):
         except Exception as e:
             print(str(e))
     VQTdll.RunVQTPAMSPSQM(0, 0, c_char_p(srcFile.encode('utf_8')), c_char_p(degFile.encode('utf_8')), 1, params)
-    time.sleep(0.5)
+    time.sleep(5)
     pass
 
 
