@@ -36,7 +36,7 @@ from Noise_Suppression.noiseFuction import  cal_noise_Supp
 allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR',
               'SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE',
               'ATTACKRELEASE','MUSICSTA','AGCDELAY','SLIENCE','FORMAT',
-              'MATCHAEC','ERLE','AECMOS','AIMOS','TRMS','ARMS']
+              'MATCHAEC','ERLE','AECMOS','AIMOS','TRMS','ARMS','NOISE']
 
 
 class computeAudioQuality():
@@ -366,7 +366,7 @@ class computeAudioQuality():
         finalName = pcm2wav(self.testFile,sample_rate=self.samplerate)
         return cal_mos_infer(finalName)
 
-    def ELRE(self):
+    def ERLE(self):
         """
         Returns
         -------
@@ -377,7 +377,7 @@ class computeAudioQuality():
         if self.__check_format(self.refFile) != self.__check_format(self.micFile) or \
             self.__check_format(self.micFile) != self.__check_format(self.testFile):
             raise TypeError('there are different parametre in inputfiles!')
-        return cal_erle(pcm2wav(self.refFile,sample_rate=self.samplerate),pcm2wav(self.micFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate),targetType=self.aecTargetType)
+        return cal_erle(refFile=pcm2wav(self.refFile,sample_rate=self.samplerate),micFile=pcm2wav(self.micFile,sample_rate=self.samplerate),testFile=pcm2wav(self.testFile,sample_rate=self.samplerate),targetType=self.aecTargetType)
 
     def MATCHAEC(self):
         """
@@ -385,12 +385,12 @@ class computeAudioQuality():
         -------
 
         """
-        if self.caliFile is None or self.micFile is None or self.testFile is None:
+        if self.caliFile is None or self.refFile is None or self.testFile is None:
             raise EOFError('lack of inputfiles!')
-        if self.__check_format(self.caliFile) != self.__check_format(self.micFile) or \
+        if self.__check_format(self.caliFile) != self.__check_format(self.refFile) or \
             self.__check_format(self.caliFile) != self.__check_format(self.testFile):
             raise TypeError('there are different parametre in inputfiles!')
-        return MATCH_AEC(pcm2wav(self.micFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate),pcm2wav(self.caliFile,sample_rate=self.samplerate),self.outFile,targetType=self.aecTargetType)
+        return MATCH_AEC(pcm2wav(self.refFile,sample_rate=self.samplerate),pcm2wav(self.testFile,sample_rate=self.samplerate),pcm2wav(self.caliFile,sample_rate=self.samplerate),self.outFile,targetType=self.aecTargetType)
 
     def SLIENCE(self):
         """
